@@ -1,14 +1,17 @@
+from typing import Optional
+
 import click
 from dask import config
 from rich.console import Console
 from rich.table import Table
 
-from coiled._beta.core import setup_logging
 from coiled.exceptions import BuildError
+from coiled.types import ArchitectureTypesEnum
+from coiled.v2.core import setup_logging
 
 from ..core import Cloud, create_software_environment, delete_software_environment
 from ..utils import COILED_SERVER
-from .utils import CONTEXT_SETTINGS, ENVIRON
+from .utils import CONTEXT_SETTINGS
 
 console = Console()
 
@@ -29,53 +32,19 @@ def env():
     type=click.Path(exists=True),
 )
 @click.option("--pip", default=None, help="Pip requirements file.", type=click.Path(exists=True))
-@click.option(
-    "--post-build",
-    default=None,
-    help="Post-build script.",
-    type=click.Path(exists=True),
-)
-@click.option(
-    "--conda-env-name",
-    default=None,
-    help=(
-        "Name of conda environment to install packages into. "
-        "Only use when using `--container`, and the image expects commands to run in "
-        'a conda environment not named "coiled"'
-    ),
-)
-@click.option(
-    "--private/--no-private",
-    default=True,
-    help="Flag to set software environment private.",
-    is_flag=True,
-)
 @click.option(
     "--force-rebuild",
     default=False,
     help="Skip checks for an existing software environment build.",
     is_flag=True,
 )
-@click.option(
-    "-e",
-    "--environ",
-    default=None,
-    type=ENVIRON,
-    multiple=True,
-    help="Custom environment variable(s).",
-)
 @click.option(
     "--account",
+    "--workspace",
     default=None,
     type=str,
-    help="Account to use for creating this software environment.",
-)
-@click.option(
-    "--new-build-backend/--no-new-build-backend",
-    is_flag=True,
-    show_default=True,
-    default=True,
-    help="Use the new build system",
+    help="Workspace to use for creating this software environment."
+    " Note: --account is deprecated, please use --workspace instead.",
 )
 @click.option(
     "--gpu-enabled",
@@ -84,19 +53,54 @@ def env():
     default=False,
     help="Set CUDA virtual package for Conda",
 )
+@click.option(
+    "--architecture",
+    type=click.Choice([e.value for e in ArchitectureTypesEnum]),
+    default=ArchitectureTypesEnum.X86_64.value,
+    show_default=True,
+    help="CPU architecture to use for the software environment",
+)
+@click.option(
+    "--region-name",
+    default=None,
+    type=str,
+    help="AWS or GCP region to use for storing this software environment.",
+)
+@click.option(
+    "--include-local-code",
+    default=False,
+    is_flag=True,
+    help="Include local code in the software environment build. "
+    "This includes editable installs and importable python files.",
+)
+@click.option(
+    "-i",
+    "--ignore-local-package",
+    multiple=True,
+    help="Ignore a local package in the software environment build."
+    " Only applies to packages included by the include-local-code option."
+    " Specify multiple times for multiple packages."
+    " Example: -i coiled -i pytorch",
+)
+@click.option(
+    "--enable-experimental-installer/--disable-experimental-installer",
+    default=None,
+    is_flag=True,
+    help="Enable experimental usage of uv to install for a pypi packages.",
+)
 def create(
     name,
     container,
     conda,
     pip,
-    post_build,
-    conda_env_name,
-    private,
     force_rebuild,
-    environ,
     account,
-    new_build_backend,
     gpu_enabled,
+    architecture,
+    region_name,
+    include_local_code,
+    enable_experimental_installer,
+    ignore_local_package,
 ):
     """Create a Coiled software environment"""
     try:
@@ -105,55 +109,58 @@ def create(
             container=container,
             conda=conda,
             pip=pip,
-            post_build=post_build,
-            conda_env_name=conda_env_name,
-            private=private,
             force_rebuild=force_rebuild,
-            environ=dict(environ),
             account=account,
-            new_build_backend=new_build_backend,
             gpu_enabled=gpu_enabled,
+            architecture=architecture,
+            region_name=region_name,
+            include_local_code=include_local_code,
+            ignore_local_packages=ignore_local_package,
+            enable_experimental_installer=enable_experimental_installer,
         )
     except BuildError as e:
-        raise click.ClickException(f"{e}")
+        raise click.ClickException(f"{e}") from e
 
 
 @env.command(context_settings=CONTEXT_SETTINGS)
 @click.argument("name")
-@click.option("--new-build-backend/--no-new-build-backend", is_flag=True, default=True)
-def delete(name: str, new_build_backend: bool):
+@click.option(
+    "--workspace", default=None, required=False, help="Coiled workspace (uses default workspace if not specified)."
+)
+def delete(name: str, workspace: Optional[str]):
     """Delete a Coiled software environment"""
-    delete_software_environment(name, new_build_backend=new_build_backend)
+    delete_software_environment(name, workspace=workspace)
 
 
 @env.command(context_settings=CONTEXT_SETTINGS)
-@click.argument("account", default=None, required=False)
-@click.option("--new-build-backend/--no-new-build-backend", is_flag=True, default=True)
-def list(account: str, new_build_backend: bool):
-    """List the Coiled software environments in an account"""
-    with Cloud(account=account) as cloud:
-        environments = cloud.list_software_environments(account, new_build_backend=new_build_backend)
-        account = cloud.default_account
-    if not new_build_backend:
-        console.print(environments)
-    else:
+@click.option(
+    "--workspace", default=None, required=False, help="Coiled workspace (uses default workspace if not specified)."
+)
+def list(workspace: str):
+    """List the Coiled software environments in a workspace"""
+    with Cloud(workspace=workspace) as cloud:
+        environments = cloud.list_software_environments(
+            workspace,
+        )
         table = Table(title="Software Environments")
         table.add_column("Name", style="cyan")
         table.add_column("Updated", style="magenta")
         table.add_column("Link", style="magenta")
         table.add_column("Status", style="green")
         server = config.get("coiled.server", COILED_SERVER).replace("8000", "5173")
-        account = account or config.get("coiled.account")
+        account = workspace or config.get("coiled.workspace", config.get("coiled.account"))
         for env_name, env_details in environments.items():
             latest_build = env_details["latest_spec"].get("latest_build")
             if latest_build:
                 build_status = latest_build["state"] if latest_build["state"] != "error" else "[red]error[/red]"
+                env_url = f"{server}/software/alias/{env_details['id']}/build/{latest_build['id']}?account={account}"
             else:
                 build_status = "n/a"
+                env_url = f"{server}/software/alias/{env_details['id']}?account={account}"
             table.add_row(
                 env_name,
                 env_details["updated"],
-                f"{server}/software/{env_details['id']}/latest?account={account}",
+                env_url,
                 build_status,
             )
         console.print(table)
